ApiErrorError class abstract

ApiErrorError

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ApiErrorError([void updates(ApiErrorErrorBuilder b)])
factory

Properties

code String
no setter
details → JsonObject?
no setter
hashCode int
The hash code for this object.
no setterinherited
message String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ApiErrorErrorBuilder)) ApiErrorError
Rebuilds the instance.
inherited
toBuilder() ApiErrorErrorBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ApiErrorError>
no setter