HistoryAnalysisResponse class abstract

HistoryAnalysisResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

HistoryAnalysisResponse([void updates(HistoryAnalysisResponseBuilder b)])
factory

Properties

assetClass HistoryAnalysisResponseAssetClassEnum?
no setter
base_ String
no setter
from String
no setter
hashCode int
The hash code for this object.
no setterinherited
interval HistoryAnalysisResponseIntervalEnum?
no setter
mode HistoryAnalysisResponseModeEnum
no setter
results → BuiltList<HistoryAnalysisResponseResultsInner>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort HistoryAnalysisResponseSortEnum?
no setter
stats bool
no setter
to String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(HistoryAnalysisResponseBuilder)) HistoryAnalysisResponse
Rebuilds the instance.
inherited
toBuilder() HistoryAnalysisResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<HistoryAnalysisResponse>
no setter