VolatilityResponseBuilder class
Constructors
Properties
- base_ ↔ String?
-
getter/setter pair
- basis ↔ VolatilityResponseBasisEnum?
-
getter/setter pair
- from ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode ↔ VolatilityResponseModeEnum?
-
getter/setter pair
-
results
↔ ListBuilder<
VolatilityResponseResultsInner> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sort ↔ VolatilityResponseSortEnum?
-
getter/setter pair
- to ↔ String?
-
getter/setter pair
- universe ↔ VolatilityResponseUniverseEnum?
-
getter/setter pair
Methods
-
build(
) → VolatilityResponse -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
VolatilityResponse other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(VolatilityResponseBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited