SafeHavenResponse class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- SafeHavenResponse([void updates(SafeHavenResponseBuilder b)])
-
factory
Properties
- base_ → String
-
no setter
- crisis → SafeHavenResponseCrisis
-
no setter
- from → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
results
→ BuiltList<
SafeHavenResponseResultsInner> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → String
-
no setter
- universe → SafeHavenResponseUniverseEnum?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(SafeHavenResponseBuilder)) → SafeHavenResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → SafeHavenResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
SafeHavenResponse> -
no setter